==> ejc-purchasingmanagement-impl-3.0.0-20220903.162409-208-sources.jar: com/ejianc/business/purchasingmanagement/controller/api/WeighinginfoApi.java <==
package com.ejianc.business.purchasingmanagement.controller.api;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.purchasingmanagement.bean.PurchasedetilEntity;
import com.ejianc.business.purchasingmanagement.bean.PurchasereceiptEntity;
import com.ejianc.business.purchasingmanagement.service.IPurchasedetilService;
import com.ejianc.business.purchasingmanagement.service.IWeighingInfoService;

import com.ejianc.business.purchasingmanagement.vo.PurchasedetilVO;
import com.ejianc.business.purchasingmanagement.vo.PurchasereceiptVO;
import com.ejianc.business.purchasingmanagement.vo.WeighingInfoVO;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;


import com.ejianc.framework.core.response.CommonResponse;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

@RestController
@RequestMapping("/api/purchasingmanagement/receiptApi/")
public class WeighinginfoApi {
    @Autowired
    private IWeighingInfoService weighinginfoService;
    @Autowired
    private IPurchasedetilService purchasedetilService;
    /**
     * @Description  新增或者修改
     */
    @RequestMapping(value = "/saveWeighinginfo", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse saveWeighinginfo(@RequestBody WeighingInfoVO WeighinginfoApiVO) {
        weighinginfoService.saveChange(WeighinginfoApiVO);
    	return CommonResponse.success("修改项目成功！");
    }


    /**
     * @Description  新增或者修改
     */
    @RequestMapping(value = "/vehicleInformation", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<List<PurchasedetilVO>> vehicleInformation(@RequestParam String numberPlate ,String orgId ) {

        QueryWrapper<PurchasedetilEntity> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("org_id",orgId);
        queryWrapper.eq("number_plate",numberPlate);
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:ss:mm");
        Calendar c = Calendar.getInstance();
        c.setTime(new Date());
        c.add(Calendar.DATE, -1);
        Date start = c.getTime();
        String qyt= format.format(start);//前一天
        qyt = qyt + " 00:00:00";
        queryWrapper.between("delivery_time",qyt,sdf.format(new Date()));
        queryWrapper.eq("status",0);
        List<PurchasedetilEntity> purchasedetilEntities= purchasedetilService.list(queryWrapper);
        List<PurchasedetilVO> purchasedetilVOS= new ArrayList<>();
        if(purchasedetilEntities.size() > 0){
            PurchasedetilVO vo = BeanMapper.map(purchasedetilEntities.get(0), PurchasedetilVO.class);
            purchasedetilVOS.add(vo);
        }
        return CommonResponse.success("查询成功！",purchasedetilVOS);
    }



}

==> ejc-purchasingmanagement-impl-3.0.0-20221017.091328-230-sources.jar: com/ejianc/business/purchasingmanagement/controller/api/WeighinginfoApi.java <==
package com.ejianc.business.purchasingmanagement.controller.api;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.purchasingmanagement.bean.PurchasedetilEntity;
import com.ejianc.business.purchasingmanagement.bean.PurchasereceiptEntity;
import com.ejianc.business.purchasingmanagement.service.IPurchasedetilService;
import com.ejianc.business.purchasingmanagement.service.IWeighingInfoService;

import com.ejianc.business.purchasingmanagement.vo.PurchasedetilVO;
import com.ejianc.business.purchasingmanagement.vo.PurchasereceiptVO;
import com.ejianc.business.purchasingmanagement.vo.WeighingInfoVO;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;


import com.ejianc.framework.core.response.CommonResponse;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

@RestController
@RequestMapping("/api/purchasingmanagement/receiptApi/")
public class WeighinginfoApi {
    @Autowired
    private IWeighingInfoService weighinginfoService;
    @Autowired
    private IPurchasedetilService purchasedetilService;
    /**
     * @Description  新增或者修改
     */
    @RequestMapping(value = "/saveWeighinginfo", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse saveWeighinginfo(@RequestBody WeighingInfoVO WeighinginfoApiVO) {
        weighinginfoService.saveChange(WeighinginfoApiVO);
    	return CommonResponse.success("修改项目成功！");
    }


    /**
     * @Description  新增或者修改
     */
    @RequestMapping(value = "/vehicleInformation", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<List<PurchasedetilVO>> vehicleInformation(@RequestParam String numberPlate ,String orgId ) {

        QueryWrapper<PurchasedetilEntity> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("org_id",orgId);
        queryWrapper.eq("number_plate",numberPlate);
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
        Calendar c = Calendar.getInstance();
        c.setTime(new Date());
        c.add(Calendar.DATE, -1);
        Date start = c.getTime();
        String qyt= format.format(start);//前一天
        qyt = qyt + " 00:00:00";
        String testTime = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date());
        queryWrapper.between("delivery_time",qyt,testTime);
//        queryWrapper.gt("delivery_time",qyt);
//        queryWrapper.le("delivery_time",sdf.format(new Date()));
        queryWrapper.eq("status",0);
        List<PurchasedetilEntity> purchasedetilEntities= purchasedetilService.list(queryWrapper);
        List<PurchasedetilVO> vos= new ArrayList<>();
        List<PurchasedetilVO> purchasedetilVOS= new ArrayList<>();
        if(purchasedetilEntities.size() > 0){
            for(PurchasedetilEntity entity : purchasedetilEntities){
                if(entity.getReceiptQuantity() == null){
                    vos.add(BeanMapper.map(entity,PurchasedetilVO.class));
                }
            }
        }
        if(vos.size() > 0){
            PurchasedetilVO vo = BeanMapper.map(vos.get(0), PurchasedetilVO.class);
            purchasedetilVOS.add(vo);
        }
        return CommonResponse.success("查询成功！",purchasedetilVOS);
    }



}
